@@ -29,24 +29,30 @@ def htmlmeta_set_http_equiv(k,v,request=None):
        request= get_current_request()
     request._htmlmeta.set_http_equiv(k,v)
 
+def htmlmeta_set_link(k,v,request=None):
+    """proxies HtmlMetaHub.set_link through request._htmlmeta"""
+    if request is None:
+       request= get_current_request()
+    request._htmlmeta.set_link(k,v)
+
 def htmlmeta_set_name(k,v,request=None):
     """proxies HtmlMetaHub.set_name through request._htmlmeta"""
     if request is None:
        request= get_current_request()
     request._htmlmeta.set_name(k,v)
 
-def htmlmeta_set(k,v,request=None):
-    """proxies HtmlMetaHub.set through request._htmlmeta"""
-    if request is None:
-       request= get_current_request()
-    request._htmlmeta.set(k,v)
-
 def htmlmeta_set_other(k,v,request=None):
     """proxies HtmlMetaHub.set_other through request._htmlmeta"""
     if request is None:
        request= get_current_request()
     request._htmlmeta.set_other(k,v)
     
+def htmlmeta_set(k,v,request=None):
+    """proxies HtmlMetaHub.set through request._htmlmeta"""
+    if request is None:
+       request= get_current_request()
+    request._htmlmeta.set(k,v)
+
 def htmlmeta_get(k,request=None):
     """proxies HtmlMetaHub.get through request._htmlmeta"""
     if request is None:
